@@ -39,7 +39,6 @@ comments = {
 licenses = {"default": "All rights reserved."}
 
 
-def template(inception, year, name, locality, country):
-    return eval(
-        f"f'Copyright (c) {inception} - {year} [{name} - {locality} - {country}]'"
-    )
+# format the copyright statement
+def template(copyright_format, inception, year, name, locality, country):
+    return eval(f"f'{copyright_format}'")
